@@ -8,6 +8,11 @@ from multidecoder.registry import decoder
 if TYPE_CHECKING:
     from multidecoder.node import Node
 
+EXECUTABLE_TYPE = "executable.filename"
+LIBRARY_TYPE = "executable.library.filename"
+
+EXT_MAP = {b".dll": LIBRARY_TYPE, b".exe": EXECUTABLE_TYPE}
+
 EXECUTABLE_RE = rb"(?i)\b\w+[.]exe\b"
 LIBRARY_RE = rb"(?i)\b\w+[.]dll\b"
 
@@ -15,10 +20,10 @@ LIBRARY_RE = rb"(?i)\b\w+[.]dll\b"
 @decoder
 def find_executable_name(data: bytes) -> list[Node]:
     """Find exe files"""
-    return regex_hits("executable.filename", EXECUTABLE_RE, data)
+    return regex_hits(EXECUTABLE_TYPE, EXECUTABLE_RE, data)
 
 
 @decoder
 def find_library(data: bytes) -> list[Node]:
     """Find dll files"""
-    return regex_hits("executable.library.filename", LIBRARY_RE, data)
+    return regex_hits(EXECUTABLE_TYPE, LIBRARY_RE, data)
