@@ -1,8 +1,9 @@
 import pytest
+
 from multidecoder.multidecoder import Multidecoder, Node
 
 
-@pytest.fixture()
+@pytest.fixture
 def md():
     return Multidecoder()
 
